import { readable, writable } from 'svelte/store';

type IntroIndex = number;

interface MemberStore {
   username: string
   intros: IntroIndex[]
}

interface Intro {
    name: string
    filename: string
    length: number
}

function createMemberStore(): MemberStore {
    const { subscribe, set, update } = writable(null)

    return {
        subscribe: subscribe,
        set: set,
        addIntro: (intro: IntroIndex) => { update((n) => n.intros.push(intro)); return intro },
        login: async (token) => {
            const response = (await (await fetch(
                'http://localhost:7756/me',
                { headers: {"token": token} })).json())

            if (response === "NoUserFound") {
                return;
            } else {
                set({ token: token, ...response.Me }) 
            }
        }
    }
}

function createIntroStore(): IntroStore {
    const { subscribe, set, update } = writable({})

    return {
        subscribe: subscribe,
        set: set,
        update: update,
        fetchIntros: async (guilds) => {
            console.debug('Fetching intros');
            console.log(guilds)

            let intros = {};

            for (const guild of guilds) {
                const response = (await (await fetch(`http://localhost:7756/intros/${guild.name}`)).json())
                    if (response !== "NoGuildFound") {
                    const guild_intros = response.Intros.map((intro) => {
                        if (!!intro.File) {
                            return { name: intro.File.friendlyName, filename: intro.File.filename }
                        } else if (!!intro.Online) {
                            return { name: intro.Online.friendlyName, url: intro.Online.url }
                        }
                    })

                    intros[guild.name] = guild_intros;
                }
            }

            console.debug('Setting Intros store');
            console.debug(intros);
            console.debug(intros[123]);
            set(intros)
        }
    }


}

export const intros: IntroStore = createIntroStore()
export const member: MemberStore = createMemberStore()

